@@ -5,13 +5,12 @@ use warnings;
 package Dancer2::Plugin::ParamKeywords;
 use Dancer2::Plugin;
 
-our $VERSION = 'v0.1.4';
+our $VERSION = 'v0.1.5';
 
 foreach my $source ( qw( route query body ) ) {
     register "$source\_param" => sub {
         my ($dsl, $param)  = @_;
-        my $hash = $dsl->app->request->params($source) || {};
-        $hash->{$param};
+        $dsl->app->request->params($source)->{$param};
     };
     
     register "$source\_params" => sub {
@@ -44,7 +43,7 @@ register_plugin for_versions => [ 2 ] ;
 
 1;
 
-# ABSTRACT: Sugar for the params() keyword
+# ABSTRACT: Sugar for the params() keyword (DEPRECATED)
 # PODNAME: Dancer2::Plugin::ParamKeywords
 
 __END__
@@ -55,11 +54,11 @@ __END__
 
 =head1 NAME
 
-Dancer2::Plugin::ParamKeywords - Sugar for the params() keyword
+Dancer2::Plugin::ParamKeywords - Sugar for the params() keyword (DEPRECATED)
 
 =head1 VERSION
 
-version v0.1.4
+version v0.1.5
 
 =head1 SYNOPSIS
 
@@ -74,6 +73,12 @@ version v0.1.4
 
 =head1 DESCRIPTION
 
+This module is deprecated with the release of L<Dancer2>'s
+L<Hash::MultiValue> parameter keywords: route_parameters,
+query_parameters, and body_parameters.  Use this plugin
+only if you are unable to upgrade your installation of
+L<Dancer2>.
+
 The default L<Dancer2::Core::Request params
 accessor|Dancer2::Core::Request/"params($source)">
 munges parameters in the following precedence from
@@ -159,7 +164,7 @@ Chris Tijerina
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Chris Tijerina.
+This software is copyright (c) 2016 by Chris Tijerina.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
